==> Cosmos7.641.tar.gz: Cosmos7.641/cosmos/Zcondc.h <==
#ifndef Zcondc_
#define  Zcondc_
!  define EFIELD  0 if Electric field is to be supplied 
!  by the user using cmyEfiled.f of which template is
!  in UserHook/.  The user may copy it to the users
!  application area, modify it and may add #include cmyEfiled.f in
!  the chook.f. Also the user must give a value of
!  >1 to the 'HowEfield' parameter  in the namelist.
!  Note simple Electric field can be specified
!  without using this but by giving HowEfield=1 in the
!  namelist parameter (HPARM). Then simple electric
!  field can be specified (together with other parameters)
#undef EFIELD 
!   dpmjet cannot be used on NEXTSTEP, so
!   you have to make the next 0. 
#ifdef NEXT486
#define  USEDPMJET    0
#else
#define  USEDPMJET    1
#endif
#undef  MATHLOUSY
#ifdef Solaris
#define MATHLOUSY
#endif

!            make DEBUG > 0 depending on the debug purpose. 

#define  DEBUG 0
!
!   choose:    Old atmosphere or new segmented atmosphere
!            define 
!               old atmosphere --> 0
!           or  new with c-spline
!               new atmosphere --> 1
!           or  new with linear interp.
!               new atmosphere --> 2
#define  ATMOSPHERE  2

!     if you want to put a lable on each particle to identify that
!     the one and the same particle crosses a given observation
!     plane more than once, make this 1 or 2.  Then the same particle
!     will have the  same label number in track record.
!     ( aTrack.label ).  If this is 0, aTrack.lable record dose not
!     exists. 
!     If 1; after any interaction (except for continuous energy
!     loss by dE/dx and deflection by B or scattering), label is
!     changed.
!     If 2: For knockon and Bremstrahlung, the survival particle
!     will have the same label. In the case of Moller scattring
!     higher enregy electrons are regarded as the survival one.
!
#define  LABELING    0
!     if you want to have a detailed info. for particle tracking
!     make the below >=1.  The user observation routine is called
!     with the following id  on the following  conditions:
!              chookobs(a, id)
!     1)  if it is >=1,  a particle is going to interact at a point given in
!         the track information, id=4
!     2)  if it is >=1,  a particle is going to die, id=5
!     3)  if it is >=2,  a particle is being discarded due to the large
!          angle (cos(angle relative to the parent) > BackAngLimit). id=6
!     4)  if it is >=3,  a particle makes a step. id=7
!        
#define  DETAILED_TRACKING 0
#endif  /* Zcondc.h */

==> Cosmos7.642.tar.gz: Cosmos7.642/cosmos/Zcondc.h <==
#ifndef Zcondc_
#define  Zcondc_
!  define EFIELD  0 if Electric field is to be supplied 
!  by the user using cmyEfield.f of which template is
!  in UserHook/.  The user may copy it to the users
!  application area, modify it and may add #include cmyEfiled.f in
!  the chook.f. Also the user must give a value of
!  >1 to the 'HowEfield' parameter  in the namelist.
!  Note simple Electric field can be specified
!  without using this but by giving HowEfield=1 in the
!  namelist parameter (HPARM). Then simple electric
!  field can be specified (together with other parameters)
#undef EFIELD 
!   dpmjet cannot be used on NEXTSTEP, so
!   you have to make the next 0. 
#ifdef NEXT486
#define  USEDPMJET    0
#else
#define  USEDPMJET    1
#endif
#undef  MATHLOUSY
!   if parameter statement does not permit to use math such as 
!      parameter::pi=asin(1.d0)*2 define MATHLOUSY
#ifdef Solaris
#define MATHLOUSY
#endif

!            make DEBUG > 0 depending on the debug purpose. 

#define  DEBUG 0
!
!   choose:    Old atmosphere or new segmented atmosphere
!            define, or  NRL time-dependent one 
!               old atmosphere --> 0
!           or  new with c-spline
!               new atmosphere --> 1
!           or  new with linear interp.
!               new atmosphere --> 2 (default)
!           or  NRL atmosphere --> 3
#define  ATMOSPHERE  2

!     if you want to put a lable on each particle to identify that
!     the one and the same particle crosses a given observation
!     plane more than once, make this 1 or 2.  Then the same particle
!     will have the  same label number in track record.
!     ( aTrack.label ).  If this is 0, aTrack.lable record dose not
!     exists. 
!     If 1; after any interaction (except for continuous energy
!     loss by dE/dx and deflection by B or scattering), label is
!     changed.
!     If 2: For knockon and Bremstrahlung, the survival particle
!     will have the same label. In the case of Moller scattring
!     higher enregy electrons are regarded as the survival one.
!
#define  LABELING    0
!     if you want to have a detailed info. for particle tracking
!     make the below >=1.  The user observation routine is called
!     with the following id  on the following  conditions:
!              chookobs(a, id)
!     1)  if it is >=1,  a particle is going to interact at a point given in
!         the track information, id=4
!     2)  if it is >=1,  a particle is going to die, id=5
!     3)  if it is >=2,  a particle is being discarded due to the large
!          angle (cos(angle relative to the parent) > BackAngLimit). id=6
!     4)  if it is >=3,  a particle makes a step. id=7
!        
#define  DETAILED_TRACKING 0
#endif  /* Zcondc.h */
